@@ -8,14 +8,15 @@ More detailed description.
 import multiprocessing as mp
 import warnings
 
-from pyrasta.crs import proj4_from
+import pyproj
 from pyrasta.io_.files import _copy_to_file
 from pyrasta.tools.calculator import _op, _raster_calculation
 from pyrasta.tools.clip import _clip_raster_by_extent, _clip_raster_by_mask
 from pyrasta.tools.conversion import _resample_raster, _padding, _rescale_raster, \
     _align_raster, _extract_bands, _merge_bands, _read_array, _xy_to_2d_index, _read_value_at, \
-    _project_raster
+    _project_raster, _array_to_raster
 from pyrasta.exceptions import RasterBaseError
+from pyrasta.tools.mask import _raster_mask
 from pyrasta.tools.merge import _merge
 from pyrasta.tools.rasterize import _rasterize
 from pyrasta.tools.stats import _histogram, _zonal_stats
@@ -138,9 +139,19 @@ class RasterBase:
         ----------
         bands: list
             list of band numbers
+
+        Returns
+        -------
         """
         return _extract_bands(self, bands)
 
+    @classmethod
+    def from_array(cls, array, crs, bounds,
+                   gdal_driver=gdal.GetDriverByName("Gtiff"),
+                   no_data=-999):
+
+        return _array_to_raster(cls, array, crs, bounds, gdal_driver, no_data)
+
     def histogram(self, nb_bins=10, normalized=True):
         """ Compute raster histogram
 
@@ -160,6 +171,23 @@ class RasterBase:
         """
         return _histogram(self, nb_bins, normalized)
 
+    def mask(self, mask, all_touched=True):
+        """ Apply mask to raster
+
+        Parameters
+        ----------
+        mask: geopandas.geodataframe or gistools.layer.GeoLayer
+            Mask layer as a GeoDataFrame or GeoLayer
+        all_touched: bool
+            if True, all touched pixels within layer boundaries are burnt,
+            when clipping raster by mask
+
+        Returns
+        -------
+
+        """
+        return _raster_mask(self, mask, all_touched)
+
     @classmethod
     def merge(cls, rasters, bounds=None, output_format="Gtiff",
               data_type=gdal.GetDataTypeByName('Float32'), no_data=-999):
@@ -299,6 +327,8 @@ class RasterBase:
             expression to calculate (must accept a collection of arrays)
         window_size: int or (int, int)
             size of window/chunk to set in memory during calculation
+            * unique value
+            * tuple of 2D coordinates (width, height)
         gdal_driver: osgeo.gdal.Driver
             GDAL driver (output format)
         data_type: int
@@ -527,7 +557,7 @@ class RasterBase:
         """ Return Coordinate Reference System
 
         """
-        return proj4_from(self._gdal_dataset.GetProjection())
+        return pyproj.CRS(self._gdal_dataset.GetProjection())
 
     @lazyproperty
     def bounds(self):
