@@ -5,7 +5,8 @@
 More detailed description.
 """
 import os
-from tempfile import mkstemp
+import uuid
+from tempfile import mkstemp, gettempdir
 
 
 def _copy_to_file(raster, out_file):
@@ -41,6 +42,27 @@ class TempFile(File):
             pass
 
 
+class NamedTempFile(TempFile):
+
+    def __init__(self, extension):
+        self.name = os.path.join(gettempdir(), str(uuid.uuid4()))
+        super().__init__(self.name + "." + extension)
+
+
+class ShapeTempFile(NamedTempFile):
+
+    def __init__(self):
+        super().__init__("shp")
+
+    def __del__(self):
+        super().__del__()
+        for ext in [".shx", ".dbf", ".prj", ".cpg"]:
+            try:
+                os.remove(self.name + ext)
+            except FileNotFoundError:
+                pass
+
+
 class RasterTempFile(TempFile):
     """ Create temporary raster file
 
